summaryrefslogtreecommitdiffstats
path: root/ppapi/c
diff options
context:
space:
mode:
authorbbudge@chromium.org <bbudge@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-06-21 23:07:04 +0000
committerbbudge@chromium.org <bbudge@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-06-21 23:07:04 +0000
commite46177921cafffdf8d911d92388f6d3b66483817 (patch)
tree7857dafa96f2eb9b76e1a013a875abc9d1120ac0 /ppapi/c
parenta86c93c574d51e430b89b41a18f72924614ade6e (diff)
downloadchromium_src-e46177921cafffdf8d911d92388f6d3b66483817.zip
chromium_src-e46177921cafffdf8d911d92388f6d3b66483817.tar.gz
chromium_src-e46177921cafffdf8d911d92388f6d3b66483817.tar.bz2
Add an IPC channel between the NaCl loader process and the renderer.
BUG=116317 TEST=manual Review URL: https://chromiumcodereview.appspot.com/10214007 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@143483 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ppapi/c')
-rw-r--r--ppapi/c/private/ppb_nacl_private.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/ppapi/c/private/ppb_nacl_private.h b/ppapi/c/private/ppb_nacl_private.h
index dc7e7a2..06b900e 100644
--- a/ppapi/c/private/ppb_nacl_private.h
+++ b/ppapi/c/private/ppb_nacl_private.h
@@ -15,17 +15,21 @@
struct PPB_NaCl_Private {
// This function launches NaCl's sel_ldr process. On success, the function
// returns true, otherwise it returns false. When it returns true, it will
// write |socket_count| nacl::Handles to imc_handles. Unless
// EnableBackgroundSelLdrLaunch is called, this method must be invoked from
// the main thread.
PP_Bool (*LaunchSelLdr)(PP_Instance instance,
const char* alleged_url,
int socket_count,
- void* imc_handles);
+ void* imc_handles,
+ void** ipc_channel_handle);
// This function starts the PPAPI proxy so the nexe can communicate with the
- // browser's renderer process.
- PP_Bool (*StartPpapiProxy)(PP_Instance instance);
+ // browser's renderer process. |ipc_channel_handle| is the pointer returned
+ // by the call to LaunchSelLdr.
+ PP_Bool (*StartPpapiProxy)(PP_Instance instance,
+ void* ipc_channel_handle);
// On POSIX systems, this function returns the file descriptor of
// /dev/urandom. On non-POSIX systems, this function returns 0.
@@ -15,17 +15,21 @@
// This function launches NaCl's sel_ldr process. On success, the function
// returns true, otherwise it returns false. When it returns true, it will
- // write |socket_count| nacl::Handles to imc_handles. Unless
+ // write |socket_count| nacl::Handles to imc_handles. |ipc_channel_handle|
+ // will point to information needed to start the IPC proxy. Unless
// EnableBackgroundSelLdrLaunch is called, this method must be invoked from
// the main thread.